summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/cpu/mips/mips1.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/cpu/mips/mips1.h')
-rw-r--r--src/devices/cpu/mips/mips1.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/devices/cpu/mips/mips1.h b/src/devices/cpu/mips/mips1.h
index 123a8ec2ae1..08c8d1fd95b 100644
--- a/src/devices/cpu/mips/mips1.h
+++ b/src/devices/cpu/mips/mips1.h
@@ -225,9 +225,10 @@ protected:
int m_icount;
enum branch_state_t : unsigned
{
- NONE = 0,
- DELAY = 1, // delay slot instruction active
- BRANCH = 2, // branch instruction active
+ NONE = 0,
+ DELAY = 1, // delay slot instruction active
+ BRANCH = 2, // branch instruction active
+ EXCEPTION = 3, // exception triggered
}
m_branch_state;
u32 m_branch_target;